@@ -15,8 +15,8 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef OPERATION_COPY
-#define OPERATION_COPY
+#ifndef OPERATIONCOPY
+#define OPERATIONCOPY
 
 #include "../include/Operation.h"
 
@@ -29,7 +29,7 @@ public:
 	OperationCopy( const Device & device,
 		       const Partition & partition_orig,
 		       const Partition & partition_new,
-		       const Partition & partition_copied) ;
+		       const Partition & partition_copied ) ;
 	
 	void apply_to_visual( std::vector<Partition> & partitions ) ;
 
@@ -41,4 +41,4 @@ private:
 
 } //GParted
 
-#endif //OPERATION_COPY
+#endif //OPERATIONCOPY
