@@ -52,20 +52,23 @@ enum FILESYSTEM
 	
 	FS_EXT2		= 4,
 	FS_EXT3		= 5,
-	FS_LINUX_SWAP	= 6,
-	FS_FAT16	= 7,
-	FS_FAT32	= 8,
-	FS_NTFS		= 9,
-	FS_REISERFS	= 10,
-	FS_REISER4	= 11,
-	FS_XFS		= 12,
-	FS_JFS		= 13,
-	FS_HFS		= 14,
-	FS_HFSPLUS	= 15,
-	FS_UFS		= 16,
+	FS_EXT4		= 6,
+	FS_LINUX_SWAP	= 7,
+	FS_FAT16	= 8,
+	FS_FAT32	= 9,
+	FS_NTFS		= 10,
+	FS_REISERFS	= 11,
+	FS_REISER4	= 12,
+	FS_XFS		= 13,
+	FS_JFS		= 14,
+	FS_HFS		= 15,
+	FS_HFSPLUS	= 16,
+	FS_UFS		= 17,
 
-	FS_USED		= 17,
-	FS_UNUSED	= 18
+	FS_USED		= 18,
+	FS_UNUSED	= 19,
+
+	FS_LVM2		= 20   
 } ;
 
 enum SIZE_UNIT
@@ -79,7 +82,7 @@ enum SIZE_UNIT
 	UNIT_TIB	= 5
 } ;
 
-//struct to store filesysteminformation
+//struct to store file system information
 struct FS
 {
 	enum Support
@@ -92,8 +95,8 @@ struct FS
 
 	FILESYSTEM filesystem ;
 	Support read ; //can we get the amount of used sectors?
-	Support get_label ;
-	Support set_label ;
+	Support read_label ;
+	Support write_label ;
 	Support create ;
 	Support grow ;
 	Support shrink ;
@@ -106,7 +109,7 @@ struct FS
 	
 	FS()
 	{
-		read = get_label = set_label = create = grow = shrink = move = check = copy = NONE;
+		read = read_label = write_label = create = grow = shrink = move = check = copy = NONE;
 		MIN = MAX = 0 ;
 	} 
 } ;
@@ -121,11 +124,13 @@ public:
 			      	      Gtk::AlignmentEnum x_align = Gtk::ALIGN_LEFT,
 			      	      Gtk::AlignmentEnum y_align = Gtk::ALIGN_CENTER,
 				      bool wrap = false,
+				      bool selectable = false,
 				      const Glib::ustring & text_color = "black" ) ;
 	static Glib::ustring num_to_str( Sector number, bool use_C_locale = false ) ;
 	static Glib::ustring get_color( FILESYSTEM filesystem ) ;
 	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf( FILESYSTEM filesystem, int width, int height ) ;
 	static Glib::ustring get_filesystem_string( FILESYSTEM filesystem ) ;
+	static Glib::ustring get_filesystem_software( FILESYSTEM filesystem ) ;
 	static Glib::ustring format_size( Sector size ) ;
 	static Glib::ustring format_time( std::time_t seconds ) ;
 	static double sector_to_unit( Sector sectors, SIZE_UNIT size_unit ) ;
@@ -136,13 +141,16 @@ public:
 				    bool use_C_locale = false ) ;
 	static Glib::ustring regexp_label( const Glib::ustring & text,
 					const Glib::ustring & regular_sub_expression ) ;
+	static Glib::ustring fat_compliant_label( const Glib::ustring & label ) ;
 	static Glib::ustring create_mtoolsrc_file( char file_name[],
                     const char drive_letter, const Glib::ustring & device_path ) ;
 	static Glib::ustring delete_mtoolsrc_file( const char file_name[] ) ;
 	static Glib::ustring trim( const Glib::ustring & src, const Glib::ustring & c = " \t\r\n" ) ;
+	static Glib::ustring cleanup_cursor( const Glib::ustring & text ) ;
+	static Glib::ustring get_lang() ;
 
 };
-	
+
 
 }//GParted
 
