@@ -1,4 +1,4 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Bart Hakvoort
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
  
 #include "../include/Win_GParted.h"
 #include "../include/GParted_Core.h"
+#include "../include/FS_Info.h"
 #include "../include/OperationCopy.h"
 #include "../include/OperationCreate.h"
 #include "../include/OperationDelete.h"
@@ -26,6 +27,7 @@
 
 #include "../include/ext2.h"
 #include "../include/ext3.h"
+#include "../include/ext4.h"
 #include "../include/fat16.h"
 #include "../include/fat32.h"
 #include "../include/linux_swap.h"
@@ -38,8 +40,14 @@
 #include "../include/reiser4.h"
 #include "../include/ufs.h"
 
+#include <set>
 #include <cerrno>
+#include <cstring>
 #include <sys/statvfs.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <dirent.h>
 
 std::vector<Glib::ustring> libparted_messages ; //see ped_exception_handler()
 
@@ -52,6 +60,7 @@ GParted_Core::GParted_Core()
 	lp_disk = NULL ;
 	lp_partition = NULL ;
 	p_filesystem = NULL ;
+	set_thread_status_message("") ;
 
 	ped_exception_set_handler( ped_exception_handler ) ; 
 
@@ -66,7 +75,7 @@ GParted_Core::GParted_Core()
 	std::cout << "libparted : " << ped_get_version() << std::endl ;
 	std::cout << "======================" << std::endl ;
 
-	//initialize filesystemlist
+	//initialize file system list
 	find_supported_filesystems() ;
 }
 
@@ -79,7 +88,10 @@ void GParted_Core::find_supported_filesystems()
 	
 	ext3 fs_ext3;
 	FILESYSTEMS .push_back( fs_ext3 .get_filesystem_support() ) ;
-	
+
+	ext4 fs_ext4;
+	FILESYSTEMS .push_back( fs_ext4 .get_filesystem_support() ) ;
+
 	fat16 fs_fat16;
 	FILESYSTEMS .push_back( fs_fat16 .get_filesystem_support() ) ;
 	
@@ -97,7 +109,7 @@ void GParted_Core::find_supported_filesystems()
 	
 	linux_swap fs_linux_swap;
 	FILESYSTEMS .push_back( fs_linux_swap .get_filesystem_support() ) ;
-	
+
 	ntfs fs_ntfs;
 	FILESYSTEMS .push_back( fs_ntfs .get_filesystem_support() ) ;
 	
@@ -112,12 +124,19 @@ void GParted_Core::find_supported_filesystems()
 
 	xfs fs_xfs;
 	FILESYSTEMS .push_back( fs_xfs .get_filesystem_support() ) ;
-	
-	//unknown filesystem (default when no match is found)
-	FS fs ; fs .filesystem = GParted::FS_UNKNOWN ;
-	FILESYSTEMS .push_back( fs ) ;
+
+	FS *fs ;
+	//lvm2 physical volume -- not a file system
+	fs = new( FS ) ;
+	fs ->filesystem = GParted::FS_LVM2 ;
+	FILESYSTEMS .push_back( * fs ) ;
+
+	//unknown file system (default when no match is found)
+	fs = new( FS ) ;
+	fs ->filesystem = GParted::FS_UNKNOWN ;
+	FILESYSTEMS .push_back( * fs ) ;
 }
-	
+
 void GParted_Core::set_user_devices( const std::vector<Glib::ustring> & user_devices ) 
 {
 	this ->device_paths = user_devices ;
@@ -128,6 +147,7 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 {
 	devices .clear() ;
 	Device temp_device ;
+	FS_Info fs_info( true ) ;  //Refresh cache of file system information
 	
 	init_maps() ;
 	
@@ -136,6 +156,11 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 	{
 		device_paths .clear() ;
 
+		//FIXME:  When libparted bug 194 is fixed, remove code to read:
+		//           /proc/partitions
+		//        This was a problem with no floppy drive yet BIOS indicated one existed.
+		//        http://parted.alioth.debian.org/cgi-bin/trac.cgi/ticket/194
+		//
 		//try to find all available devices
 		std::ifstream proc_partitions( "/proc/partitions" ) ;
     	if ( proc_partitions )
@@ -145,13 +170,19 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
     		std::string device ;
     		while ( getline( proc_partitions, line ) )
     		{
+    			//Whole disk devices are the ones we want.
     			//Device names without a trailing digit refer to the whole disk.
-    			//These whole disk devices are the ones we want.
     			device = Utils::regexp_label(line, "^[\t ]+[0-9]+[\t ]+[0-9]+[\t ]+[0-9]+[\t ]+([^0-9]+)$") ;
+    			//Device names that end with a #[^p]# are HP Smart Array Devices (disks)
+    			//E.g., device = /dev/cciss/c0d0, partition = /dev/cciss/c0d0p1
+    			if ( device == "" )
+    				device = Utils::regexp_label(line, "^[\t ]+[0-9]+[\t ]+[0-9]+[\t ]+[0-9]+[\t ]+(.*[0-9]+[^p]{1}[0-9]+)$") ;
     			if ( device != "" )
     			{
     				//try to have libparted detect the device and add it to the list
     				device = "/dev/" + device;
+    				/*TO TRANSLATORS: looks like Scanning /dev/sda */ 
+    				set_thread_status_message( String::ucompose ( _("Scanning %1"), device ) ) ;
     				ped_device_get( device .c_str() ) ;
     			}
     		}
@@ -170,6 +201,8 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 			char * buf = static_cast<char *>( malloc( lp_device ->sector_size ) ) ;
 			if ( buf )
 			{
+				/*TO TRANSLATORS: looks like Confirming /dev/sda */ 
+				set_thread_status_message( String::ucompose ( _("Confirming %1"), lp_device ->path ) ) ;
 				if ( ped_device_open( lp_device ) )
 				{
 					if ( ped_device_read( lp_device, buf, 0, 1 ) )
@@ -187,11 +220,13 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 	}
 
 	for ( unsigned int t = 0 ; t < device_paths .size() ; t++ ) 
-	{ 
+	{
+		/*TO TRANSLATORS: looks like Searching /dev/sda partitions */ 
+		set_thread_status_message( String::ucompose ( _("Searching %1 partitions"), device_paths[ t ] ) ) ;
 		if ( open_device_and_disk( device_paths[ t ], false ) )
 		{
 			temp_device .Reset() ;
-			
+
 			//device info..
 			temp_device .add_path( device_paths[ t ] ) ;
 			temp_device .add_paths( get_alternate_paths( temp_device .get_path() ) ) ;
@@ -242,10 +277,22 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 
 	//clear leftover information...	
 	//NOTE that we cannot clear mountinfo since it might be needed in get_all_mountpoints()
+	set_thread_status_message("") ;
 	alternate_paths .clear() ;
 	fstab_info .clear() ;
 }
 
+void GParted_Core::set_thread_status_message( Glib::ustring msg )
+{
+	//Remember to clear status message when finished with thread.
+	thread_status_message = msg ;
+}
+
+Glib::ustring GParted_Core::get_thread_status_message( )
+{
+	return thread_status_message ;
+}
+
 bool GParted_Core::snap_to_cylinder( const Device & device, Partition & partition, Glib::ustring & error ) 
 {
 	if ( ! partition .strict )
@@ -506,7 +553,7 @@ void GParted_Core::init_maps()
 	read_mountpoints_from_file( "/etc/mtab", mount_info ) ;
 	read_mountpoints_from_file( "/etc/fstab", fstab_info ) ;
 	
-	//sort the mountpoints and remove duplicates.. (no need to do this for fstab_info)
+	//sort the mount points and remove duplicates.. (no need to do this for fstab_info)
 	for ( iter_mp = mount_info .begin() ; iter_mp != mount_info .end() ; ++iter_mp )
 	{
 		std::sort( iter_mp ->second .begin(), iter_mp ->second .end() ) ;
@@ -562,7 +609,7 @@ void GParted_Core::read_mountpoints_from_file( const Glib::ustring & filename,
 			{
 				line = mountpoint ;
 				
-				//see if mountpoint contains spaces and deal with it
+				//see if mount point contains spaces and deal with it
 				index = line .find( "\\040" ) ;
 				if ( index < line .length() )
 					line .replace( index, 4, " " ) ;
@@ -591,6 +638,7 @@ void GParted_Core::set_device_partitions( Device & device )
 {
 	int EXT_INDEX = -1 ;
 	char * lp_path ;//we have to free the result of ped_partition_get_path()..
+	FS_Info fs_info ;  //Use cache of file system information
 	
 	//clear partitions
 	device .partitions .clear() ;
@@ -648,7 +696,16 @@ void GParted_Core::set_device_partitions( Device & device )
 				break;
 		}
 
-		get_label( partition_temp ) ;
+		//Avoid reading additional file system information if there is no path
+		if ( partition_temp .get_path() != "" )
+		{
+			bool label_found = false ;
+			partition_temp .label = fs_info .get_label( partition_temp .get_path(), label_found ) ;
+			if ( ! label_found )
+				read_label( partition_temp ) ;
+
+			partition_temp .uuid = fs_info .get_uuid( partition_temp .get_path() ) ;
+		}
 
 		partition_temp .messages .insert( partition_temp .messages .end(),
 						  libparted_messages. begin(),
@@ -679,7 +736,7 @@ void GParted_Core::set_device_partitions( Device & device )
 
 GParted::FILESYSTEM GParted_Core::get_filesystem() 
 {
-	//standard libparted filesystems..
+	//standard libparted file systems..
 	if ( lp_partition && lp_partition ->fs_type )
 	{
 		if ( Glib::ustring( lp_partition ->fs_type ->name ) == "extended" )
@@ -687,8 +744,22 @@ GParted::FILESYSTEM GParted_Core::get_filesystem()
 		else if ( Glib::ustring( lp_partition ->fs_type ->name ) == "ext2" )
 			return GParted::FS_EXT2 ;
 		else if ( Glib::ustring( lp_partition ->fs_type ->name ) == "ext3" )
-			return GParted::FS_EXT3 ;
-		else if ( Glib::ustring( lp_partition ->fs_type ->name ) == "linux-swap" )
+		{
+			//FIXME:  Temporary code to detect ext4.
+			//        Replace when libparted bug #188 "ext4 detected as ext3" is fixed.
+			//        http://parted.alioth.debian.org/cgi-bin/trac.cgi/ticket/188
+			FS_Info fs_info ;
+			temp = fs_info .get_fs_type( Glib::ustring( ped_partition_get_path( lp_partition ) ) ) ; 
+			if ( temp == "ext4" || temp == "ext4dev" )
+				return GParted::FS_EXT4 ;
+			else
+				return GParted::FS_EXT3 ;
+		}
+		else if ( Glib::ustring( lp_partition ->fs_type ->name ) == "ext4" )
+			return GParted::FS_EXT4 ;
+		else if ( Glib::ustring( lp_partition ->fs_type ->name ) == "linux-swap" ||
+		          Glib::ustring( lp_partition ->fs_type ->name ) == "linux-swap(new)" ||
+		          Glib::ustring( lp_partition ->fs_type ->name ) == "linux-swap(old)" )
 			return GParted::FS_LINUX_SWAP ;
 		else if ( Glib::ustring( lp_partition ->fs_type ->name ) == "fat16" )
 			return GParted::FS_FAT16 ;
@@ -711,7 +782,8 @@ GParted::FILESYSTEM GParted_Core::get_filesystem()
 	}
 	
 	
-	//other filesystems libparted couldn't detect (i've send patches for these filesystems to the parted guys)
+	//other file systems libparted couldn't detect (i've send patches for these file systems to the parted guys)
+	// - no patches sent to parted for lvm2
 	char buf[512] ;
 
 	ped_device_open( lp_device );
@@ -722,30 +794,50 @@ GParted::FILESYSTEM GParted_Core::get_filesystem()
 	
 	if ( Glib::ustring( buf ) == "ReIsEr4" )
 		return GParted::FS_REISER4 ;		
-		
-	//no filesystem found....
-	temp = _( "Unable to detect filesystem! Possible reasons are:" ) ;
+
+	//lvm2
+	//NOTE: lvm2 is not a file system but we do wish to recognize the Physical Volume
+	char magic1[16] ;
+	char magic2[16] ;
+
+	ped_device_open( lp_device );
+	ped_geometry_read( & lp_partition ->geom, buf, 1, 1 ) ;
+	strncpy(magic1, buf+0, 8) ;  magic1[8] = '\0' ; //set and terminate string
+	strncpy(magic2, buf+24, 4) ; magic2[4] = '\0' ; //set and terminate string
+	ped_device_close( lp_device );
+
+	if (    Glib::ustring( magic1 ) == "LABELONE"
+		 && Glib::ustring( magic2 ) == "LVM2" )
+	{
+		temp = _( "Logical Volume Management is not yet supported." ) ;
+		temp += "\n" ;
+		partition_temp .messages .push_back( temp ) ;
+		return GParted::FS_LVM2 ;
+	}
+
+	//no file system found....
+	temp = _( "Unable to detect file system! Possible reasons are:" ) ;
 	temp += "\n-"; 
-	temp += _( "The filesystem is damaged" ) ;
+	temp += _( "The file system is damaged" ) ;
 	temp += "\n-" ; 
-	temp += _( "The filesystem is unknown to GParted" ) ;
+	temp += _( "The file system is unknown to GParted" ) ;
 	temp += "\n-"; 
-	temp += _( "There is no filesystem available (unformatted)" ) ; 
+	temp += _( "There is no file system available (unformatted)" ) ; 
 	
 	partition_temp .messages .push_back( temp ) ;
 	
 	return GParted::FS_UNKNOWN ;
 }
 	
-void GParted_Core::get_label( Partition & partition )
+void GParted_Core::read_label( Partition & partition )
 {
 	if ( partition .type != TYPE_EXTENDED )
 	{
-		switch( get_fs( partition .filesystem ) .get_label )
+		switch( get_fs( partition .filesystem ) .read_label )
 		{
 			case FS::EXTERNAL:
 				if ( set_proper_filesystem( partition .filesystem ) )
-					p_filesystem ->get_label( partition ) ;
+					p_filesystem ->read_label( partition ) ;
 				break ;
 			case FS::LIBPARTED:
 				break ;
@@ -811,7 +903,8 @@ void GParted_Core::set_mountpoints( std::vector<Partition> & partitions )
 	{
 		if ( ( partitions[ t ] .type == GParted::TYPE_PRIMARY ||
 		       partitions[ t ] .type == GParted::TYPE_LOGICAL ) &&
-		     partitions[ t ] .filesystem != GParted::FS_LINUX_SWAP )
+		     partitions[ t ] .filesystem != GParted::FS_LINUX_SWAP &&
+		     partitions[ t ] .filesystem != GParted::FS_LVM2 )
 		{
 			if ( partitions[ t ] .busy )
 			{
@@ -826,7 +919,7 @@ void GParted_Core::set_mountpoints( std::vector<Partition> & partitions )
 				}
 
 				if ( partitions[ t ] .get_mountpoints() .empty() )
-					partitions[ t ] .messages .push_back( _("Unable to find mountpoint") ) ;
+					partitions[ t ] .messages .push_back( _("Unable to find mount point") ) ;
 			}
 			else
 			{
@@ -844,13 +937,14 @@ void GParted_Core::set_used_sectors( std::vector<Partition> & partitions )
 {
 	struct statvfs sfs ; 
 	
-	temp = _("Unable to read the contents of this filesystem!") ;
+	temp = _("Unable to read the contents of this file system!") ;
 	temp += "\n" ;
 	temp += _("Because of this some operations may be unavailable.") ;
 	
 	for ( unsigned int t = 0 ; t < partitions .size() ; t++ )
 	{
 		if ( partitions[ t ] .filesystem != GParted::FS_LINUX_SWAP &&
+		     partitions[ t ] .filesystem != GParted::FS_LVM2 &&
 		     partitions[ t ] .filesystem != GParted::FS_UNKNOWN )
 		{
 			if ( partitions[ t ] .type == GParted::TYPE_PRIMARY ||
@@ -1053,8 +1147,9 @@ bool GParted_Core::create_partition( Partition & new_partition, OperationDetail
 	
 bool GParted_Core::create_filesystem( const Partition & partition, OperationDetail & operationdetail ) 
 {
+	/*TO TRANSLATORS: looks like create new ext3 file system */ 
 	operationdetail .add_child( OperationDetail( String::ucompose(
-							_("create new %1 filesystem"),
+							_("create new %1 file system"),
 							Utils::get_filesystem_string( partition .filesystem ) ) ) ) ;
 	
 	bool succes = false ;
@@ -1079,7 +1174,7 @@ bool GParted_Core::create_filesystem( const Partition & partition, OperationDeta
 
 bool GParted_Core::format( const Partition & partition, OperationDetail & operationdetail )
 {	
-	//remove all filesystem signatures...
+	//remove all file system signatures...
 	erase_filesystem_signatures( partition ) ;
 
 	return set_partition_type( partition, operationdetail ) && create_filesystem( partition, operationdetail ) ;
@@ -1123,11 +1218,11 @@ bool GParted_Core::label_partition( const Partition & partition, OperationDetail
 	bool succes = false ;
 	if ( partition .type != TYPE_EXTENDED )
 	{
-		switch( get_fs( partition .filesystem ) .set_label )
+		switch( get_fs( partition .filesystem ) .write_label )
 		{
 			case FS::EXTERNAL:
 				succes = set_proper_filesystem( partition .filesystem ) &&
-					 p_filesystem ->set_label( partition, operationdetail .get_last_child() ) ;
+					 p_filesystem ->write_label( partition, operationdetail .get_last_child() ) ;
 				break ;
 			case FS::LIBPARTED:
 				break ;
@@ -1200,7 +1295,7 @@ bool GParted_Core::move( const Device & device,
 	if ( check_repair_filesystem( partition_old, operationdetail ) )
 	{
 		//NOTE: logical partitions are preceeded by metadata. To prevent this metadata from being
-		//overwritten we move the partition first and only then the filesystem when moving to the left.
+		//overwritten we move the partition first and only then the file system when moving to the left.
 		//(maybe i should do some reading on how non-msdos disklabels deal with metadata....)
 		if ( partition_new .sector_start < partition_old .sector_start )
 		{
@@ -1208,7 +1303,7 @@ bool GParted_Core::move( const Device & device,
 	       	   	{
 				if ( ! move_filesystem( partition_old, partition_new, operationdetail ) )
 				{
-					operationdetail .add_child( OperationDetail( _("rollback last change to the partitiontable") ) ) ;
+					operationdetail .add_child( OperationDetail( _("rollback last change to the partition table") ) ) ;
 
 					if ( resize_move_partition( partition_new, partition_old, operationdetail .get_last_child() ) )
 						operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
@@ -1237,14 +1332,14 @@ bool GParted_Core::move_filesystem( const Partition & partition_old,
 				    OperationDetail & operationdetail ) 
 {
 	if ( partition_new .sector_start < partition_old .sector_start )
-		operationdetail .add_child( OperationDetail( _("move filesystem to the left") ) ) ;
+		operationdetail .add_child( OperationDetail( _("move file system to the left") ) ) ;
 	else if ( partition_new .sector_start > partition_old .sector_start )
-		operationdetail .add_child( OperationDetail( _("move filesystem to the right") ) ) ;
+		operationdetail .add_child( OperationDetail( _("move file system to the right") ) ) ;
 	else
 	{
-		operationdetail .add_child( OperationDetail( _("move filesystem") ) ) ;
+		operationdetail .add_child( OperationDetail( _("move file system") ) ) ;
 		operationdetail .get_last_child() .add_child( 
-			OperationDetail( _("new and old filesystem have the same positition -- skipping this operation"),
+			OperationDetail( _("new and old file system have the same position -- skipping this operation"),
 					 STATUS_NONE,
 					 FONT_ITALIC ) ) ;
 
@@ -1365,7 +1460,7 @@ bool GParted_Core::resize( const Partition & partition_old,
 		if ( ! check_repair_filesystem( partition_new, operationdetail ) )
 			succes = false ;
 
-		//expand filesystem to fit exactly in partition
+		//expand file system to fit exactly in partition
 		if ( ! maximize_filesystem( partition_new, operationdetail ) )
 			succes = false ;
 			
@@ -1542,17 +1637,17 @@ bool GParted_Core::resize_filesystem( const Partition & partition_old,
 	{
 		if ( partition_new .get_length() < partition_old .get_length() )
 		{
-			operationdetail .add_child( OperationDetail( _("shrink filesystem") ) ) ;
+			operationdetail .add_child( OperationDetail( _("shrink file system") ) ) ;
 			action = get_fs( partition_old .filesystem ) .shrink ;
 		}
 		else if ( partition_new .get_length() > partition_old .get_length() )
-			operationdetail .add_child( OperationDetail( _("grow filesystem") ) ) ;
+			operationdetail .add_child( OperationDetail( _("grow file system") ) ) ;
 		else
 		{
-			operationdetail .add_child( OperationDetail( _("resize filesystem") ) ) ;
+			operationdetail .add_child( OperationDetail( _("resize file system") ) ) ;
 			operationdetail .get_last_child() .add_child( 
 				OperationDetail( 
-					_("new and old filesystem have the same size -- skipping this operation"),
+					_("new and old file system have the same size -- skipping this operation"),
 					STATUS_NONE,
 					FONT_ITALIC ) ) ;
 		
@@ -1587,12 +1682,12 @@ bool GParted_Core::resize_filesystem( const Partition & partition_old,
 	
 bool GParted_Core::maximize_filesystem( const Partition & partition, OperationDetail & operationdetail ) 
 {
-	operationdetail .add_child( OperationDetail( _("grow filesystem to fill the partition") ) ) ;
+	operationdetail .add_child( OperationDetail( _("grow file system to fill the partition") ) ) ;
 
 	if ( get_fs( partition .filesystem ) .grow == GParted::FS::NONE )
 	{
 		operationdetail .get_last_child() .add_child( 
-			OperationDetail( _("growing is not available for this filesystem"),
+			OperationDetail( _("growing is not available for this file system"),
 					  STATUS_NONE,
 					  FONT_ITALIC ) ) ;
 
@@ -1611,7 +1706,7 @@ bool GParted_Core::copy( const Partition & partition_src,
 	if ( partition_dst .get_length() < partition_src .get_length() )
 	{	
 		operationdetail .add_child( OperationDetail( 
-			_("the destination is smaller than the sourcepartition"), STATUS_ERROR, FONT_ITALIC ) ) ;
+			_("the destination is smaller than the source partition"), STATUS_ERROR, FONT_ITALIC ) ) ;
 
 		return false ;
 	}
@@ -1625,7 +1720,7 @@ bool GParted_Core::copy( const Partition & partition_src,
 		if ( succes && set_partition_type( partition_dst, operationdetail ) )
 		{
 			operationdetail .add_child( OperationDetail( 
-				String::ucompose( _("copy filesystem of %1 to %2"),
+				String::ucompose( _("copy file system of %1 to %2"),
 						  partition_src .get_path(),
 						  partition_dst .get_path() ) ) ) ;
 						
@@ -1669,7 +1764,7 @@ bool GParted_Core::copy_filesystem_simulation( const Partition & partition_src,
 				      	       const Partition & partition_dst,
 			      		       OperationDetail & operationdetail ) 
 {
-	operationdetail .add_child( OperationDetail( _("perform readonly test") ) ) ;
+	operationdetail .add_child( OperationDetail( _("perform read-only test") ) ) ;
 	
 	bool succes = copy_filesystem( partition_src, partition_dst, operationdetail .get_last_child(), true ) ;
 
@@ -1723,7 +1818,8 @@ bool GParted_Core::copy_filesystem( const Glib::ustring & src_device,
 
 	operationdetail .add_child( OperationDetail( _("finding optimal blocksize"), STATUS_NONE ) ) ;
 
-	Sector optimal_blocksize = readonly ? 128 : 64, N = 32768 ;
+	Sector benchmark_blocksize = readonly ? 128 : 64, N = 65536 ;
+	Sector optimal_blocksize = benchmark_blocksize ;
 	Sector offset_read = src_start,
 	       offset_write = dst_start ;
 
@@ -1739,24 +1835,18 @@ bool GParted_Core::copy_filesystem( const Glib::ustring & src_device,
 	double smallest_time = 1000000 ;
 	bool succes = true ;
 
+	//Benchmark copy times using different block sizes to determine optimal size
 	while ( succes &&
-		timer .elapsed() <= smallest_time && 
-		std::llabs( done ) + N <= length && 
-		optimal_blocksize * 2 < N )
+		llabs( done ) + N <= length && 
+		benchmark_blocksize <= N )
 	{
-		if ( done != 0 ) 
-		{
-			smallest_time = timer .elapsed() ;
-			optimal_blocksize *= 2 ;
-		}
-
 		timer .reset() ;
 		succes = copy_blocks( src_device, 
 	  		     	      dst_device,
 			     	      offset_read + done, 
 			     	      offset_write + done,
 			     	      N, 
-			     	      optimal_blocksize,
+			     	      benchmark_blocksize,
 			     	      operationdetail .get_last_child(),
 				      readonly,
 				      total_done ) ;
@@ -1764,16 +1854,20 @@ bool GParted_Core::copy_filesystem( const Glib::ustring & src_device,
 
 		operationdetail .get_last_child() .get_last_child() .add_child( OperationDetail( 
 			String::ucompose( _("%1 seconds"), timer .elapsed() ), STATUS_NONE, FONT_ITALIC ) ) ;
-		
+
+		if ( timer .elapsed() <= smallest_time )
+		{
+			smallest_time = timer .elapsed() ;
+			optimal_blocksize = benchmark_blocksize ; 
+		}
+		benchmark_blocksize *= 2 ;
+
 		if ( ( dst_start > src_start ) )
 			done -= N ;
 		else
 			done += N ;
 	}
 	
-	if ( timer .elapsed() > smallest_time )
-		optimal_blocksize /= 2 ;
-	
 	if ( succes )
 		operationdetail .get_last_child() .add_child( OperationDetail( String::ucompose( _("optimal blocksize is %1 sectors (%2)"),
 					 							 optimal_blocksize,
@@ -1785,7 +1879,7 @@ bool GParted_Core::copy_filesystem( const Glib::ustring & src_device,
 		      	    	    dst_device,
 		      	    	    src_start + ( dst_start > src_start ? 0 : done ),
 		      	    	    dst_start + ( dst_start > src_start ? 0 : done ),
-		      	    	    length - std::llabs( done ), 
+		      	    	    length - llabs( done ), 
 		      	    	    optimal_blocksize,
 		      	    	    operationdetail,
 			    	    readonly,
@@ -1805,7 +1899,7 @@ void GParted_Core::rollback_transaction( const Partition & partition_src,
 	{
 		operationdetail .add_child( OperationDetail( _("rollback last transaction") ) ) ;
 
-		//find out exactly which part of the filesystem was copied (and to where it was copied)..
+		//find out exactly which part of the file system was copied (and to where it was copied)..
 		Partition temp_src = partition_src ;
 		Partition temp_dst = partition_dst ;
 
@@ -1830,7 +1924,7 @@ void GParted_Core::rollback_transaction( const Partition & partition_src,
 bool GParted_Core::check_repair_filesystem( const Partition & partition, OperationDetail & operationdetail ) 
 {
 	operationdetail .add_child( OperationDetail( 
-				String::ucompose( _("check filesystem on %1 for errors and (if possible) fix them"),
+				String::ucompose( _("check file system on %1 for errors and (if possible) fix them"),
 						  partition .get_path() ) ) ) ;
 	
 	bool succes = false ;
@@ -1838,7 +1932,7 @@ bool GParted_Core::check_repair_filesystem( const Partition & partition, Operati
 	{
 		case GParted::FS::NONE:
 			operationdetail .get_last_child() .add_child(
-				OperationDetail( _("checking is not available for this filesystem"),
+				OperationDetail( _("checking is not available for this file system"),
 						 STATUS_NONE,
 						 FONT_ITALIC ) ) ;
 
@@ -1864,7 +1958,7 @@ bool GParted_Core::check_repair_filesystem( const Partition & partition, Operati
 bool GParted_Core::set_partition_type( const Partition & partition, OperationDetail & operationdetail )
 {
 	operationdetail .add_child( OperationDetail(
-				String::ucompose( _("set partitiontype on %1"), partition .get_path() ) ) ) ;
+				String::ucompose( _("set partition type on %1"), partition .get_path() ) ) ) ;
 	
 	bool return_value = false ;
 	
@@ -1873,7 +1967,12 @@ bool GParted_Core::set_partition_type( const Partition & partition, OperationDet
 		PedFileSystemType * fs_type = 
 			ped_file_system_type_get( Utils::get_filesystem_string( partition .filesystem ) .c_str() ) ;
 
+		//If not found, and FS is linux-swap, then try linux-swap(new)
+		if ( ! fs_type && Utils::get_filesystem_string( partition .filesystem ) == "linux-swap" )
+			fs_type = ped_file_system_type_get( "linux-swap(new)" ) ;
+
 		//default is Linux (83)
+		//FIXME:  Currently HFS+ and HFS get set to 83, but should be AF.
 		if ( ! fs_type )
 			fs_type = ped_file_system_type_get( "ext2" ) ;
 
@@ -1886,7 +1985,7 @@ bool GParted_Core::set_partition_type( const Partition & partition, OperationDet
 			     commit() )
 			{
 				operationdetail .get_last_child() .add_child( 
-					OperationDetail( String::ucompose( _("new partitiontype: %1"),
+					OperationDetail( String::ucompose( _("new partition type: %1"),
 									   lp_partition ->fs_type ->name ),
 							 STATUS_NONE,
 							 FONT_ITALIC ) ) ;
@@ -1959,7 +2058,7 @@ bool GParted_Core::copy_blocks( const Glib::ustring & src_device,
 	if ( lp_device_src && lp_device_dst && ped_device_open( lp_device_src ) && ped_device_open( lp_device_dst ) )
 	{
 		Glib::ustring error_message ;
-		buf = static_cast<char *>( malloc( std::llabs( blocksize ) * 512 ) ) ;
+		buf = static_cast<char *>( malloc( llabs( blocksize ) * 512 ) ) ;
 		if ( buf )
 		{
 			ped_device_sync( lp_device_dst ) ;
@@ -1980,7 +2079,7 @@ bool GParted_Core::copy_blocks( const Glib::ustring & src_device,
 			operationdetail .get_last_child() .add_child( OperationDetail( "", STATUS_NONE ) ) ;
 			
 			Glib::Timer timer_progress_timeout, timer_total ;
-			while( succes && std::llabs( done ) < length )
+			while( succes && llabs( done ) < length )
 			{
 				succes = copy_block( lp_device_src,
 						     lp_device_dst,
@@ -1995,7 +2094,7 @@ bool GParted_Core::copy_blocks( const Glib::ustring & src_device,
 				if ( timer_progress_timeout .elapsed() >= 0.5 )
 				{
 					set_progress_info( length,
-							   std::llabs( done + blocksize ),
+							   llabs( done + blocksize ),
 							   timer_total,
 							   operationdetail .get_last_child() .get_last_child(),
 							   readonly ) ;
@@ -2014,13 +2113,13 @@ bool GParted_Core::copy_blocks( const Glib::ustring & src_device,
 
 		//final description
 		operationdetail .get_last_child() .get_last_child() .set_description( 
-			String::ucompose( readonly ? _("%1 of %2 read") : _("%1 of %2 copied"), std::llabs( done ), length ), FONT_ITALIC ) ;
+			String::ucompose( readonly ? _("%1 of %2 read") : _("%1 of %2 copied"), llabs( done ), length ), FONT_ITALIC ) ;
 		
 		if ( ! succes && ! error_message .empty() )
 			operationdetail .get_last_child() .add_child( 
 				OperationDetail( error_message, STATUS_NONE, FONT_ITALIC ) ) ;
 		
-		total_done += std::llabs( done ) ;
+		total_done += llabs( done ) ;
 	
 		//close and destroy the devices..
 		ped_device_close( lp_device_src ) ;
@@ -2047,7 +2146,7 @@ bool GParted_Core::copy_block( PedDevice * lp_device_src,
 {
 	if ( blocksize < 0 )
 	{
-		blocksize = std::llabs( blocksize ) ;
+		blocksize = llabs( blocksize ) ;
 		offset_src -= ( blocksize -1 ) ;
 		offset_dst -= ( blocksize -1 ) ;
 	}
@@ -2196,6 +2295,7 @@ bool GParted_Core::set_proper_filesystem( const FILESYSTEM & filesystem )
 	{
 		case FS_EXT2		: p_filesystem = new ext2() ;	 	break ;
 		case FS_EXT3		: p_filesystem = new ext3() ; 		break ;
+		case FS_EXT4		: p_filesystem = new ext4() ; 		break ;
 		case FS_LINUX_SWAP	: p_filesystem = new linux_swap() ; 	break ;
 		case FS_FAT16		: p_filesystem = new fat16() ; 		break ;
 		case FS_FAT32		: p_filesystem = new fat32() ; 		break ;
@@ -2224,7 +2324,7 @@ bool GParted_Core::erase_filesystem_signatures( const Partition & partition )
 
 		if ( lp_partition && ped_file_system_clobber( & lp_partition ->geom ) )
 		{
-			//filesystems not yet supported by libparted
+			//file systems not yet supported by libparted
 			if ( ped_device_open( lp_device ) )
 			{
 				//reiser4 stores "ReIsEr4" at sector 128
@@ -2248,7 +2348,7 @@ bool GParted_Core::update_bootsector( const Partition & partition, OperationDeta
 	if ( partition .filesystem == FS_NTFS )
 	{
 		operationdetail .add_child( OperationDetail( 
-			String::ucompose( _("updating bootsector of %1 filesystem on %2"),
+			String::ucompose( _("updating boot sector of %1 file system on %2"),
 					  Utils::get_filesystem_string( partition .filesystem ),
 					  partition .get_path() ) ) ) ;
 
