@@ -1,4 +1,4 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Bart Hakvoort
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ Win_GParted::Win_GParted( const std::vector<Glib::ustring> & user_devices )
 	
 	try
 	{
-		this ->set_icon_from_file( GNOME_ICONDIR "/gparted.png" ) ;
+		this ->set_default_icon_name( "gparted" ) ;
 	}
 	catch ( Glib::Exception & e )
 	{ 
@@ -141,9 +141,6 @@ void Win_GParted::init_menubar()
 	image = manage( new Gtk::Image( Gtk::Stock::HARDDISK, Gtk::ICON_SIZE_MENU ) );
 	menu ->items() .push_back( Gtk::Menu_Helpers::ImageMenuElem( _("_Devices"), *image ) ) ; 
 	
-	menu ->items() .push_back( Gtk::Menu_Helpers::SeparatorElem( ) );
-	menu ->items() .push_back( Gtk::Menu_Helpers::MenuElem(
-		_("_Show Features"), sigc::mem_fun( *this, &Win_GParted::menu_gparted_features ) ) );
 	menu ->items() .push_back( Gtk::Menu_Helpers::SeparatorElem( ) );
 	menu ->items() .push_back( Gtk::Menu_Helpers::StockMenuElem( 
 		Gtk::Stock::QUIT, sigc::mem_fun(*this, &Win_GParted::menu_gparted_quit) ) );
@@ -167,7 +164,7 @@ void Win_GParted::init_menubar()
 		* manage( new Gtk::Image( Gtk::Stock::APPLY, Gtk::ICON_SIZE_MENU ) ), 
 		sigc::mem_fun(*this, &Win_GParted::activate_apply) ) );
 	menubar_main .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("_Edit"), *menu ) );
-	
+
 	//view
 	menu = manage( new Gtk::Menu() ) ;
 	menu ->items() .push_back( Gtk::Menu_Helpers::CheckMenuElem(
@@ -175,21 +172,29 @@ void Win_GParted::init_menubar()
 	menu ->items() .push_back( Gtk::Menu_Helpers::CheckMenuElem( 
 		_("Pending _Operations"), sigc::mem_fun(*this, &Win_GParted::menu_view_operations) ) );
 	menubar_main .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("_View"), *menu ) );
-	
+
+	menu ->items() .push_back( Gtk::Menu_Helpers::SeparatorElem( ) );
+	menu ->items() .push_back( Gtk::Menu_Helpers::MenuElem(
+		_("_File System Support"), sigc::mem_fun( *this, &Win_GParted::menu_gparted_features ) ) );
+
 	//device
 	menu = manage( new Gtk::Menu() ) ;
-	menu ->items() .push_back( Gtk::Menu_Helpers::MenuElem( Glib::ustring( _("_Create Partition Table") ) + " ...",
+	menu ->items() .push_back( Gtk::Menu_Helpers::MenuElem( Glib::ustring( _("_Create Partition Table") ) + "...",
 								sigc::mem_fun(*this, &Win_GParted::activate_disklabel) ) );
 	menubar_main .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("_Device"), *menu ) );
-		
+
 	//partition
 	init_partition_menu() ;
 	menubar_main .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("_Partition"), menu_partition ) );
-	
+
 	//help
 	menu = manage( new Gtk::Menu() ) ;
-	menu ->items() .push_back(Gtk::Menu_Helpers::StockMenuElem(
-		Gtk::Stock::HELP, sigc::mem_fun(*this, &Win_GParted::menu_help_contents) ) );
+	menu ->items() .push_back( Gtk::Menu_Helpers::ImageMenuElem( 
+		_("_Contents"), 
+		Gtk::AccelKey("F1"),
+		* manage( new Gtk::Image( Gtk::Stock::HELP, Gtk::ICON_SIZE_MENU ) ), 
+		sigc::mem_fun(*this, &Win_GParted::menu_help_contents) ) );
+	menu ->items() .push_back( Gtk::Menu_Helpers::SeparatorElem( ) );
 	menu ->items() .push_back( Gtk::Menu_Helpers::StockMenuElem(
 		Gtk::Stock::ABOUT, sigc::mem_fun(*this, &Win_GParted::menu_help_about) ) );
 
@@ -218,7 +223,19 @@ void Win_GParted::init_toolbar()
 	
 	//RESIZE/MOVE
 	image = manage( new Gtk::Image( Gtk::Stock::GOTO_LAST, Gtk::ICON_SIZE_BUTTON ) );
-	toolbutton = Gtk::manage(new Gtk::ToolButton( *image, _("Resize/Move") ));
+	Glib::ustring str_temp = _("Resize/Move") ;
+	//Condition string split and Undo button.
+	//  for longer translated string, split string in two and skip the Undo button to permit full toolbar to display
+	//  FIXME:  Is there a better way to do this, perhaps without the conditional?  At the moment this seems to be the best compromise.
+	bool display_undo = true ;
+	if( str_temp .length() > 14 ) {
+		size_t index = str_temp .find( "/" ) ;
+		if ( index != Glib::ustring::npos ) {
+			str_temp .replace( index, 1, "\n/" ) ;
+			display_undo = false ;
+		}
+	}
+	toolbutton = Gtk::manage(new Gtk::ToolButton( *image, str_temp ));
 	toolbutton ->signal_clicked().connect( sigc::mem_fun(*this, &Win_GParted::activate_resize) );
 	toolbar_main.append(*toolbutton);
 	TOOLBAR_RESIZE_MOVE = index++ ;
@@ -241,12 +258,15 @@ void Win_GParted::init_toolbar()
 	index++ ;
 	
 	//UNDO and APPLY
-	toolbutton = Gtk::manage(new Gtk::ToolButton(Gtk::Stock::UNDO));
-	toolbutton ->signal_clicked().connect( sigc::mem_fun(*this, &Win_GParted::activate_undo) );
-	toolbar_main.append(*toolbutton);
-	TOOLBAR_UNDO = index++ ;
-	toolbutton ->set_sensitive( false );
-	toolbutton ->set_tooltip(tooltips, _("Undo Last Operation") );		
+	if ( display_undo ) {
+		//Undo button is displayed only if translated language "Resize/Move" is not too long.  See above setting of this condition.
+		toolbutton = Gtk::manage(new Gtk::ToolButton(Gtk::Stock::UNDO));
+		toolbutton ->signal_clicked().connect( sigc::mem_fun(*this, &Win_GParted::activate_undo) );
+		toolbar_main.append(*toolbutton);
+		TOOLBAR_UNDO = index++ ;
+		toolbutton ->set_sensitive( false );
+		toolbutton ->set_tooltip(tooltips, _("Undo Last Operation") );
+	}
 	
 	toolbutton = Gtk::manage(new Gtk::ToolButton(Gtk::Stock::APPLY));
 	toolbutton ->signal_clicked().connect( sigc::mem_fun(*this, &Win_GParted::activate_apply) );
@@ -310,7 +330,7 @@ void Win_GParted::init_partition_menu()
 	index++ ;
 	
 	image = manage( new Gtk::Image( Gtk::Stock::CONVERT, Gtk::ICON_SIZE_MENU ) );
-	/*TO TRANSLATORS: menuitem which holds a submenu with filesystems.. */
+	/*TO TRANSLATORS: menuitem which holds a submenu with file systems.. */
 	menu_partition .items() .push_back(
 			Gtk::Menu_Helpers::ImageMenuElem( _("_Format to"),
 							  *image,
@@ -325,7 +345,7 @@ void Win_GParted::init_partition_menu()
 						     sigc::mem_fun( *this, &Win_GParted::toggle_swap_mount_state ) ) );
 	MENU_TOGGLE_MOUNT_SWAP = index++ ;
 		
-	/*TO TRANSLATORS: menuitem which holds a submenu with mountpoints.. */
+	/*TO TRANSLATORS: menuitem which holds a submenu with mount points.. */
 	menu_partition .items() .push_back(
 			Gtk::Menu_Helpers::MenuElem( _("_Mount on"), * manage( new Gtk::Menu() ) ) ) ;
 	MENU_MOUNT = index++ ;
@@ -363,8 +383,13 @@ Gtk::Menu * Win_GParted::create_format_menu()
 {
 	menu = manage( new Gtk::Menu() ) ;
 
-	for ( unsigned int t =0; t < gparted_core .get_filesystems() .size() -1 ; t++ )
+	for ( unsigned int t =0; t < gparted_core .get_filesystems() .size() ; t++ )
 	{
+		//Skip lvm2 and unknown because these are not file systems
+		if( gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LVM2 ||
+			gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_UNKNOWN )
+			continue ;
+
 		hbox = manage( new Gtk::HBox() );
 			
 		//the colored square
@@ -410,7 +435,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "" ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//size
@@ -418,7 +443,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "" ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//path
@@ -429,7 +454,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "" ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	vbox_info .pack_start( *table, Gtk::PACK_SHRINK );
@@ -447,7 +472,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL );
-	device_info .push_back( Utils::mk_label( "" ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//heads
@@ -455,7 +480,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "" ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//sectors/track
@@ -463,7 +488,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "" ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL );
 	
 	//cylinders
@@ -471,7 +496,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;
-	device_info .push_back( Utils::mk_label( "" ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	//total sectors
@@ -479,7 +504,7 @@ void Win_GParted::init_device_info()
 			0, 1,
 			top, bottom,
 			Gtk::FILL );
-	device_info .push_back( Utils::mk_label( "" ) ) ;
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
 	
 	vbox_info .pack_start( *table, Gtk::PACK_SHRINK );
@@ -570,6 +595,10 @@ void Win_GParted::show_pulsebar( const Glib::ustring & status_message )
 			Gtk::Main::iteration();
 		
 		usleep( 10000 );
+
+		Glib::ustring tmp_msg = gparted_core .get_thread_status_message() ;
+		if ( tmp_msg != "" )
+			statusbar .push( tmp_msg ) ;
 	}
 	
 	thread ->join() ;
@@ -810,9 +839,50 @@ void Win_GParted::set_valid_operations()
 			else
 				required_size = copied_partition .get_length() ;
 
-			if ( ( required_size + devices[ current_device ] .cylsize ) <= selected_partition .get_length() )
+			//  /* Copy Primary not at start of disk to within Extended partition */
+			//  Adjust when a primary partition is copied and pasted
+			//  into an unallocated space in an extended partition
+			//  of an MSDOS partition table.
+			//  Since the Extended Boot Record requires an additional track,
+			//  this must be considered in the required space for the
+			//  destination (selected) partition.
+			//  NOTE:  This problem does not occur for a primary partition
+			//  at the the start of the disk because the size of the EBR and
+			//  Master Boot Record are the same.
+			//
+			//  /* Copy Primary not at start of disk to Primary at start of disk */
+			//  Also Adjust when a primary partition that does not start at the
+			//  beginning of the disk is copied and pasted
+			//  into an unallocated space at the start of the disk device.
+			//  Since the Master Boot Record requires an additional track,
+			//  this must be considered in the required space for the
+			//  destination (selected) partition.
+			//
+			//  Because the largest unit used in the GUI is one
+			//  cylinder size (round to cylinders), the space
+			//  needed in the destination partition needs to be increased
+			//  by one cylinder size.
+			if (   (/* Copy Primary not at start of disk to within Extended partition */
+				       copied_partition .type == TYPE_PRIMARY
+				    && copied_partition .sector_start > devices[ current_device ] .sectors /* 63 for MSDOS Partition Table */
+				    && devices[ current_device ] .disktype == "msdos" 
+				    && selected_partition .type == TYPE_UNALLOCATED
+				    && selected_partition .inside_extended
+				   )
+				|| ( /* Copy Primary not at start of disk to Primary at start of disk */
+				       copied_partition .type == TYPE_PRIMARY
+				    && copied_partition .sector_start > devices[ current_device ] .sectors /* 63 for MSDOS Partition Table */
+				    && devices[ current_device ] .disktype == "msdos" 
+				    && selected_partition .type == TYPE_UNALLOCATED
+				    && selected_partition .sector_start <= devices[ current_device ] .sectors  /* Beginning of disk device */
+				    && ! selected_partition .inside_extended
+				   )
+			   )
+				required_size += devices[ current_device ] .cylsize ;
+
+			if ( required_size <= selected_partition .get_length() )
 				allow_paste( true ) ;
-		}			
+		}
 		
 		return ;
 	}
@@ -848,7 +918,7 @@ void Win_GParted::set_valid_operations()
 			allow_copy( true ) ;
 		
 		//only allow labelling of real partitions that support labelling
-		if ( selected_partition .status == GParted::STAT_REAL && fs .set_label )
+		if ( selected_partition .status == GParted::STAT_REAL && fs .write_label )
 			allow_label_partition( true ) ;
 
 		if ( selected_partition .get_mountpoints() .size() )
@@ -875,10 +945,11 @@ void Win_GParted::set_valid_operations()
 		if ( ! copied_partition .get_path() .empty() &&
 		     copied_partition .get_length() <= selected_partition .get_length() &&
 		     selected_partition .status == GParted::STAT_REAL &&
-		     copied_partition != selected_partition )
+		     copied_partition != selected_partition &&
+		     selected_partition .type == GParted::TYPE_UNALLOCATED )
 		     allow_paste( true ) ;
 
-		//see if we can somehow check/repair this filesystem....
+		//see if we can somehow check/repair this file system....
 		if ( fs .check && selected_partition .status == GParted::STAT_REAL )
 			allow_check( true ) ;
 	}
@@ -1003,7 +1074,7 @@ void Win_GParted::menu_gparted_refresh_devices()
 	{
 		Gtk::MessageDialog dialog(
 			*this,
-			_("The kernel is unable to re-read the partitiontables on the following devices:") + 
+			_("The kernel is unable to re-read the partition tables on the following devices:") + 
 			Glib::build_path( "", readonly_paths ),
 			false,
 			Gtk::MESSAGE_WARNING,
@@ -1130,20 +1201,54 @@ void Win_GParted::menu_view_operations()
 		close_operationslist() ;
 }
 
-void Win_GParted::menu_help_contents()
+void Win_GParted::show_help_dialog (const char *link_id /* For context sensitive help */)
 {
-	Gtk::MessageDialog dialog( *this,
-				   _("Sorry, not yet implemented."),
-				   false,
-				   Gtk::MESSAGE_INFO,
-				   Gtk::BUTTONS_OK,
-				   true );
+/* Original concept for show_help_dialog is from file-roller project
+ * gtk-utils.c revision 1967, Tue Aug 7 06:18:42 2007 UTC
+ * See http://fileroller.sourceforge.net/
+ * 
+ * Modified to work with GParted by Curtis Gedak :-)
+ */
+	GError *err = NULL;
+	char *command;
+	const char *lang;
+	char *uri = NULL;
+	int i;
+	GdkScreen *gscreen;
 
-	dialog .set_secondary_text( _( "Please visit http://gparted.sf.net for more information and support.") ) ;
+	const char * const * langs = g_get_language_names ();
 
-	dialog .run();
+	for (i = 0; langs[i]; i++) {
+		lang = langs[i];
+		if (strchr (lang, '.')) {
+			continue;
+		}
+
+		uri = g_build_filename( GPARTED_DATADIR,
+								"/gnome/help/gparted/",
+								lang,
+								"/gparted.xml",
+								NULL );
+					
+		if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
+                    break;
+		}
+	}
+	
+	if (link_id) {
+		command = g_strconcat ("gnome-open ghelp://", uri, "?", link_id, NULL);
+	} else {
+		command = g_strconcat ("gnome-open ghelp://", uri,  NULL);
+	}
+
+	gscreen = gdk_screen_get_default();
+	gdk_spawn_command_line_on_screen (gscreen, command, &err);
 }
 
+void Win_GParted::menu_help_contents()
+{
+	show_help_dialog( NULL);
+}
 
 void Win_GParted::menu_help_about()
 {
@@ -1153,10 +1258,10 @@ void Win_GParted::menu_help_about()
 	dialog .set_transient_for( *this ) ;
 	
 	dialog .set_name( _("GParted") ) ;
-	dialog .set_logo( this ->get_icon() ) ;
+	dialog .set_logo_icon_name( "gparted" ) ;
 	dialog .set_version( VERSION ) ;
 	dialog .set_comments( _( "GNOME Partition Editor" ) ) ;
-	dialog .set_copyright( "Copyright © 2004-2008 Bart Hakvoort" ) ;
+	dialog .set_copyright( "Copyright © 2004-2009 Bart Hakvoort" ) ;
 
 	//authors
 	strings .push_back( "Bart Hakvoort <gparted@users.sf.net>" ) ;
@@ -1170,7 +1275,7 @@ void Win_GParted::menu_help_about()
 	strings .clear() ;
 
 	/*TO TRANSLATORS: your name(s) here please, if there are more translators put newlines (\n) between the names.
-	  It's a good idea to provide the url of your translationteam as well. Thanks! */
+	  It's a good idea to provide the url of your translation team as well. Thanks! */
 	Glib::ustring str_credits = _("translator-credits") ;
 	if ( str_credits != "translator-credits" )
 		dialog .set_translator_credits( str_credits ) ;
@@ -1321,7 +1426,7 @@ void Win_GParted::activate_paste()
 		{
 			Dialog_Partition_Copy dialog( gparted_core .get_fs( copied_partition .filesystem ),
 						      devices[ current_device ] .cylsize ) ;
-			//we don't need the messages/mountpoints of the source partition.
+			//we don't need the messages/mount points of the source partition.
 			copied_partition .messages .clear() ;
 			copied_partition .clear_mountpoints() ;
 			dialog .Set_Data( selected_partition, copied_partition ) ;
@@ -1345,6 +1450,7 @@ void Win_GParted::activate_paste()
 	{
 		Partition partition_new = selected_partition ;
 		partition_new .filesystem = copied_partition .filesystem ;
+		partition_new .label = copied_partition .label ;
 		partition_new .color = copied_partition .color ;
 		partition_new .set_used( copied_partition .sectors_used ) ;
 		partition_new .messages .clear() ;
@@ -1501,7 +1607,7 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 	     fs .MAX && selected_partition .get_length() > fs .MAX ) 
 	{
 		Gtk::MessageDialog dialog( *this,
-					   String::ucompose( _("Cannot format this filesystem to %1."),
+					   String::ucompose( _("Cannot format this file system to %1."),
 						   	     Utils::get_filesystem_string( new_fs ) ) ,
 					   false,
 					   Gtk::MESSAGE_ERROR,
@@ -1510,12 +1616,12 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 
 		if ( selected_partition .get_length() < fs .MIN )
 			dialog .set_secondary_text( String::ucompose( 
-						_( "A %1 filesystem requires a partition of at least %2."),
+						_( "A %1 file system requires a partition of at least %2."),
 						Utils::get_filesystem_string( new_fs ),
 						Utils::format_size( fs .MIN ) ) );
 		else
 			dialog .set_secondary_text( String::ucompose( 
-						_( "A partition with a %1 filesystem has a maximum size of %2."),
+						_( "A partition with a %1 file system has a maximum size of %2."),
 						Utils::get_filesystem_string( new_fs ),
 						Utils::format_size( fs .MAX ) ) );
 		
@@ -1538,7 +1644,7 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 	part_temp .status = GParted::STAT_FORMATTED ;
 	
 	//if selected_partition is NEW we simply remove the NEW operation from the list and
-	//add it again with the new filesystem
+	//add it again with the new file system
 	if ( selected_partition .status == GParted::STAT_NEW )
 	{
 		//remove operation which creates this partition
@@ -1600,9 +1706,9 @@ void Win_GParted::thread_unmount_partition( bool * succes, Glib::ustring * error
 	if ( *succes && failed_mountpoints .size() )
 	{
 		*succes = false ;
-		*error = _("The partition could not be unmounted from the following mountpoints:") ;
+		*error = _("The partition could not be unmounted from the following mount points:") ;
 		*error += "\n\n<i>" + Glib::build_path( "\n", failed_mountpoints ) + "</i>\n\n" ;
-		*error +=  _("Most likely other partitions are also mounted on these mountpoints. You are advised to unmount them manually.") ;
+		*error +=  _("Most likely other partitions are also mounted on these mount points. You are advised to unmount them manually.") ;
 	}
 	else
 		*error = "<i>" + Glib::build_path( "\n", errors ) + "</i>" ;
@@ -1860,8 +1966,12 @@ void Win_GParted::activate_apply()
 				   Gtk::MESSAGE_WARNING,
 				   Gtk::BUTTONS_NONE,
 				   true );
-	dialog .set_secondary_text( _( "It is recommended to backup valuable data before proceeding.") ) ;
-	dialog .set_title( _( "Apply operations to harddisk" ) );
+	Glib::ustring temp;
+	temp =  _( "Editing partitions has the potential to cause LOSS of DATA.") ;
+	temp += "\n" ;
+	temp += _( "You are advised to backup your data before proceeding." ) ;
+	dialog .set_secondary_text( temp ) ;
+	dialog .set_title( _( "Apply operations to device" ) );
 	
 	dialog .add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
 	dialog .add_button( Gtk::Stock::APPLY, Gtk::RESPONSE_OK );
