@@ -33,7 +33,7 @@ FS fat32::get_filesystem_support()
 	FS fs ;
 	fs .filesystem = GParted::FS_FAT32 ;
 		
-	//find out if we can create fat32 filesystems
+	//find out if we can create fat32 file systems
 	if ( ! Glib::find_program_in_path( "mkdosfs" ) .empty() )
 		fs .create = GParted::FS::EXTERNAL ;
 	
@@ -44,8 +44,8 @@ FS fat32::get_filesystem_support()
 	}
 
 	if ( ! Glib::find_program_in_path( "mlabel" ) .empty() ) {
-		fs .get_label = FS::EXTERNAL ;
-		fs .set_label = FS::EXTERNAL ;
+		fs .read_label = FS::EXTERNAL ;
+		fs .write_label = FS::EXTERNAL ;
 	}
 	
 	//resizing of start and endpoint are provided by libparted
@@ -62,7 +62,7 @@ FS fat32::get_filesystem_support()
 
 void fat32::set_used_sectors( Partition & partition ) 
 {
-	//FIXME: i've encoutered a readonly fat32 filesystem.. this won't work with the -a ... best check also without the -a
+	//FIXME: i've encoutered a readonly fat32 file system.. this won't work with the -a ... best check also without the -a
 	exit_status = Utils::execute_command( "dosfsck -a -v " + partition .get_path(), output, error, true ) ;
 	if ( exit_status == 0 || exit_status == 1 || exit_status == 256 )
 	{
@@ -91,7 +91,7 @@ void fat32::set_used_sectors( Partition & partition )
 	}
 }
 
-void fat32::get_label( Partition & partition )
+void fat32::read_label( Partition & partition )
 {
 	//Create mtools config file
 	char fname[] = "/tmp/gparted-XXXXXXXX" ;
@@ -105,7 +105,7 @@ void fat32::get_label( Partition & partition )
 
 	if ( ! Utils::execute_command( cmd, output, error, true ) )
 	{
-		partition .label = Utils::regexp_label( output, "Volume label is ([^(]*)" );
+		partition .label = Utils::trim( Utils::regexp_label( output, "Volume label is ([^(]*)" ) ) ;
 	}
 	else
 	{
@@ -120,7 +120,7 @@ void fat32::get_label( Partition & partition )
 	err_msg = Utils::delete_mtoolsrc_file( fname );
 }
 
-bool fat32::set_label( const Partition & partition, OperationDetail & operationdetail )
+bool fat32::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
 	//Create mtools config file
 	char fname[] = "/tmp/gparted-XXXXXXXX" ;
@@ -132,7 +132,7 @@ bool fat32::set_label( const Partition & partition, OperationDetail & operationd
 	if( partition .label .empty() )
 		cmd = String::ucompose( "export MTOOLSRC=%1 && mlabel -c %2:", fname, dletter ) ;
 	else
-		cmd = String::ucompose( "export MTOOLSRC=%1 && mlabel %2:\"%3\"", fname, dletter, partition .label ) ;
+		cmd = String::ucompose( "export MTOOLSRC=%1 && mlabel %2:\"%3\"", fname, dletter, Utils::fat_compliant_label( partition .label ) ) ;
 	operationdetail .add_child( OperationDetail( cmd, STATUS_NONE, FONT_BOLD_ITALIC ) ) ;
 	
 	int exit_status = Utils::execute_command( cmd, output, error ) ;
@@ -151,7 +151,7 @@ bool fat32::set_label( const Partition & partition, OperationDetail & operationd
 
 bool fat32::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkdosfs -F32 -v -n \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkdosfs -F32 -v -n \"" + Utils::fat_compliant_label( new_partition .label ) + "\" " + new_partition .get_path(), operationdetail ) ;
 }
 
 bool fat32::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
