@@ -34,7 +34,7 @@ FS linux_swap::get_filesystem_support()
 	}
 
 	if ( ! Glib::find_program_in_path( "vol_id" ) .empty() )
-		fs .get_label = FS::EXTERNAL ;
+		fs .read_label = FS::EXTERNAL ;
 
 	fs .copy = GParted::FS::GPARTED ;
 	fs .move = GParted::FS::GPARTED ;
@@ -46,7 +46,7 @@ void linux_swap::set_used_sectors( Partition & partition )
 {
 }
 
-void linux_swap::get_label( Partition & partition )
+void linux_swap::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "vol_id " + partition .get_path(), output, error, true ) )
 	{
@@ -62,7 +62,7 @@ void linux_swap::get_label( Partition & partition )
 	}
 }
 
-bool linux_swap::set_label( const Partition & partition, OperationDetail & operationdetail )
+bool linux_swap::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
 	return true ;
 }
@@ -74,8 +74,9 @@ bool linux_swap::create( const Partition & new_partition, OperationDetail & oper
 
 bool linux_swap::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
+	/*TO TRANSLATORS: looks like create new linux-swap file system */ 
 	operationdetail .add_child( OperationDetail( 
-		String::ucompose( _("create new %1 filesystem"), Utils::get_filesystem_string( FS_LINUX_SWAP ) ) ) ) ;
+		String::ucompose( _("create new %1 file system"), Utils::get_filesystem_string( FS_LINUX_SWAP ) ) ) ) ;
 	if ( create( partition_new, operationdetail .get_last_child() ) ) 
 	{
 		operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
