@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 Bart
+/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ int main( int argc, char *argv[] )
 					   Gtk::MESSAGE_ERROR,
 					   Gtk::BUTTONS_OK ) ;
 		dialog .set_secondary_text(
-				_("Since GParted can be a weapon of mass destruction only root may run it.") ) ;
+				_("Since GParted is a powerful tool capable of destroying partition tables and vast amounts of data, only root may run it.") ) ;
 		
 		dialog .run() ;
 		exit( 0 ) ;
