@@ -33,8 +33,8 @@ FS ntfs::get_filesystem_support()
 	}
 
 	if ( ! Glib::find_program_in_path( "ntfslabel" ) .empty() ) {
-		fs .get_label = FS::EXTERNAL ;
-		fs .set_label = FS::EXTERNAL ;
+		fs .read_label = FS::EXTERNAL ;
+		fs .write_label = FS::EXTERNAL ;
 	}
 
 	if ( ! Glib::find_program_in_path( "mkntfs" ) .empty() )
@@ -45,7 +45,7 @@ FS ntfs::get_filesystem_support()
 	{
 		fs .grow = GParted::FS::EXTERNAL ;
 		
-		if ( fs .read ) //needed to determine a min filesystemsize..
+		if ( fs .read ) //needed to determine a min file system size..
 			fs .shrink = GParted::FS::EXTERNAL ;
 	}
 	
@@ -82,7 +82,7 @@ void ntfs::set_used_sectors( Partition & partition )
 	}
 }
 
-void ntfs::get_label( Partition & partition )
+void ntfs::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "ntfslabel --force " + partition .get_path(), output, error, true ) )
 	{
@@ -98,20 +98,20 @@ void ntfs::get_label( Partition & partition )
 	}
 }
 
-bool ntfs::set_label( const Partition & partition, OperationDetail & operationdetail )
+bool ntfs::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
 	return ! execute_command( "ntfslabel --force " + partition .get_path() + " \"" + partition .label + "\"", operationdetail ) ;
 }
 
 bool ntfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkntfs -Q -vv -L \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkntfs -Q -v -L \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
 }
 
 bool ntfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	bool return_value = false ;
-	Glib::ustring str_temp = "ntfsresize -P --force --force " + partition_new .get_path() ;
+	Glib::ustring str_temp = "ntfsresize -P --force " + partition_new .get_path() ;
 	
 	if ( ! fill_partition )
 	{
